@@ -15,6 +15,7 @@ use List::Util qw[ min max reduce shuffle];
 use List::MoreUtils qw(uniq);
 use List::AllUtils qw(sum);
 use Statistics::Basic qw(:all);
+use Storable qw(dclone);
 use IO::Tee;
 use Set::Intersection;
 use List::Compare;
@@ -51,7 +52,7 @@ convchanceseed makeflatvarnsnum calcoverlaps calcmediumiters getitersnum definer
 callcase callblocks deffiles makefilename extractcase setlaunch exe start
 _clean_ getblocks getblockelts getrootname definerootcases populatewinners 
 getitem getline getlines getcase getstepsvar tell wash flattenbox enrichbox filterbox givesize 
-$configfile $mypath $exeonfiles $generatechance $file $preventsim $fileconfig $outfile $toshell $report 
+$configfile $mypath $exeonfiles $generatechance $file $preventsim $fileconfig $outfile $tofile $report 
 $simnetwork @themereports %simtitles %reporttitles %retrievedata 
 @keepcolumns @weights @weightsaim @varthemes_report @varthemes_variations @varthemes_steps 
 @rankdata @rankcolumn @reporttempsdata @reportcomfortdata %reportdata 
@@ -61,7 +62,7 @@ $simnetwork @themereports %simtitles %reporttitles %retrievedata
 $target %dowhat
 );
 
-$VERSION = '0.47.5'; # our $VERSION = '';
+$VERSION = '0.47.7'; # our $VERSION = '';
 $ABSTRACT = 'Sim::OPT it a tool for detailed metadesign. It manages parametric explorations through the ESP-r building performance simulation platform and performs optimization by block coordinate descent.';
 
 #################################################################################
@@ -162,7 +163,7 @@ sub present
 	foreach (@_)
 	{
 		say "### $_ : " . dump($_);
-		say TOSHELL "### $_ : " . dump($_);
+		say TOFILE "### $_ : " . dump($_);
 	}
 }
 	
@@ -660,13 +661,13 @@ sub filterbox
 	@arr = @_;
 	my @basket; 
 	my @box;
-	foreach my $case (@arr)
+	foreach my $case ( @arr )
 	{
 		my $elt = $case->[0];
 		if ( not ( $elt ~~ @box ) )
 		{
 			my @bucket;
-			foreach $caseagain (@arr)
+			foreach $caseagain ( @arr )
 			{
 				my $el = $caseagain->[0];
 				if ( $elt ~~ $el )
@@ -675,14 +676,14 @@ sub filterbox
 				}
 			}
 			my $parent = $bucket[0];
-			push (@basket, $parent);
-			foreach (@basket)
+			push ( @basket, $parent );
+			foreach ( @basket )
 			{
-				push (@box, $_->[0]);
+				push ( @box, $_->[0] );
 			}
 		}
 	}
-	return (@basket);
+	return( @basket );
 }
 
 sub callcase # IT PROCESSES THE CASES.
@@ -727,7 +728,7 @@ sub callcase # IT PROCESSES THE CASES.
 	#}
 	
 	#open( OUTFILE, ">>$outfile" ) or die "Can't open $outfile: $!"; 
-	open( TOSHELL, ">>$toshell" ) or die "Can't open $toshell: $!"; 
+	open( TOFILE, ">>$tofile" ) or die "Can't open $tofile: $!"; 
 	
 	#if ( ($countcase > 0) or ($countblock > 0) )
 	#{
@@ -944,7 +945,7 @@ sub exe
 		$dirfiles{simcases} = $result[0]; #say $tee "\$dirfiles{simcases} : " . dump( $dirfiles{simcases} );
 		$dirfiles{simstruct} = $result[1]; 
 	}
-	
+
 	if ( $dowhat{retrieve} eq "y" )
 	{ 
 		say $tee "#Calling retrieval of results for case " . ($countcase +1) . ", block " . ($countblock + 1) . ".";
@@ -957,7 +958,7 @@ sub exe
 		$dirfiles{retstruct} = $result[1];
 		$dirfiles{notecases} = $result[2];
 	}
-	
+
 	if ( $dowhat{report} eq "y" )
 	{ 
 		say $tee "#Calling reporting of results for case " . ($countcase +1) . ", block " . ($countblock + 1) . ".";
@@ -972,7 +973,7 @@ sub exe
 		$dirfiles{mergecases} = $result[3];
 		$repfile = $result[4];
 	}
-	
+
 	if ( $dowhat{descend} eq "y" )
 	{ 
 		say $tee "#Calling descent in case " . ($countcase +1) . ", block " . ($countblock + 1) . ".";
@@ -984,7 +985,7 @@ sub exe
 		$dirfiles{descendcases} = $result[0];
 		$dirfiles{descendstruct} = $result[1];
 	}
-	
+
 	if ( $dowhat{substitutenames} eq "y" )
 	{
 		 Sim::OPT::Report::filter_reports( 
@@ -993,7 +994,7 @@ sub exe
 			dirfiles => \%dirfiles
 		} );
 	}
-	
+
 	if ( $dowhat{filterconverted} eq "y" )
 	{
 		 Sim::OPT::Report::convert_filtered_reports( 
@@ -1002,7 +1003,7 @@ sub exe
 			dirfiles => \%dirfiles
 		} );
 	}
-	
+
 	if ( $dowhat{make3dtable} eq "y" )
 	{
 		 Sim::OPT::Report::maketable( 
@@ -1038,12 +1039,12 @@ sub opt
 	
 	&start;
 	# eval `cat $configfile`; # The file where the program data are
-	
+
 	require $configfile;
 	#if ( not ( $outfile ) ) { $outfile = "$mypath/$file-$fileconfig-feedback.txt"; } 
-	if ( not ( $toshell ) ) { $toshell = "$mypath/$file-toshell.txt"; } 
+	if ( not ( $tofile ) ) { $tofile = "$mypath/$file-tofile.txt"; } 
 	
-	$tee = new IO::Tee(\*STDOUT, ">>$toshell"); # GLOBAL ZZZ
+	$tee = new IO::Tee(\*STDOUT, ">>$tofile"); # GLOBAL ZZZ
 
 #	if ($casefile) { eval `cat $casefile` or die( "$!" ); }
 #	if ($chancefile) { eval `cat $chancefile` or die( "$!" ); }
@@ -1051,7 +1052,7 @@ sub opt
 	print "\nNow in Sim::OPT.\n";
 		
 	#open( OUTFILE, ">>$outfile" ) or die "Can't open $outfile: $!"; 
-	open( TOSHELL, ">>$toshell" ) or die "Can't open $toshell: $!"; 
+	open( TOFILE, ">>$tofile" ) or die "Can't open $tofile: $!"; 
 		
 	#unless (-e "$mypath") 
 	#{ 
@@ -1062,7 +1063,7 @@ sub opt
 	#}
 	#unless (-e "$mypath") 
 	#{ 
-	#	print TOSHELL "mkdir $mypath\n\n"; 
+	#	print TOFILE "mkdir $mypath\n\n"; 
 	#}
 	
 	if ( not ( $target ) ) { $target = "opt"; }
@@ -1132,7 +1133,7 @@ sub opt
 	}
 	
 	close(OUTFILE);
-	close(TOSHELL);
+	close(TOFILE);
 	exit;
 } # END 
 
